# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="1.1.2"></a>
## <small>1.1.2 (2019-10-27)</small>

* fix: export shadow DOM style injector ([a7e7807](https://github.com/znck/vue-runtime-helpers/commit/a7e7807))



<a name="1.1.1"></a>
## <small>1.1.1 (2019-10-26)</small>

* fix: createInjectorShadow API ([91cb784](https://github.com/znck/vue-runtime-helpers/commit/91cb784))



<a name="1.1.0"></a>
## 1.1.0 (2019-10-26)

* feat: Add shadow DOM style injector ([c31fe75](https://github.com/znck/vue-runtime-helpers/commit/c31fe75))



<a name="1.0.2"></a>
## <small>1.0.2 (2019-08-16)</small>

* fix: Use Buffer.from instead of btoa ([f080c21](https://github.com/znck/vue-runtime-helpers/commit/f080c21))



<a name="1.0.1"></a>
## <small>1.0.1 (2019-06-14)</small>

* chore: fix type ([806a4a7](https://github.com/znck/vue-runtime-helpers/commit/806a4a7))
* chore: update changelog ([4517901](https://github.com/znck/vue-runtime-helpers/commit/4517901))
* fix: Lazily get document.head (#2) ([02d9dfa](https://github.com/znck/vue-runtime-helpers/commit/02d9dfa)), closes [#2](https://github.com/znck/vue-runtime-helpers/issues/2)



<a name="1.0.0"></a>
## 1.0.0 (2019-01-17)

* feat: Add CJS module ([fbba6fa](https://github.com/znck/vue-runtime-helpers/commit/fbba6fa))
* feat: Publish ES6 module ([4b1caaa](https://github.com/znck/vue-runtime-helpers/commit/4b1caaa))
* test: Runtime helper functions ([dd2135f](https://github.com/znck/vue-runtime-helpers/commit/dd2135f))


### BREAKING CHANGE

* `normalize-component.js` moved to `dist/normalize-component.js`


<a name="0.1.2"></a>
## [0.1.2](https://github.com/znck/vue-runtime-helpers/compare/v0.1.1...v0.1.2) (2018-05-13)
